@@ -4,7 +4,7 @@
 modname = 'worker'
 distname = 'cubicweb-worker'
 
-numversion = (3, 0, 4)
+numversion = (3, 1, 0)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
@@ -13,7 +13,8 @@ author_email = 'contact@logilab.fr'
 description = 'asynchronous workers in your instance'
 web = 'http://www.cubicweb.org/project/%s' % distname
 
-__depends__ =  {'cubicweb': '>= 3.17.0'}
+__depends__ =  {'cubicweb': '>= 3.19.3',
+                'cubicweb-subprocess': None}
 __recommends__ = {}
 
 pyversions = ['2.6']
